@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20120531';
+our $VERSION = '0.20120629';
 
-# Table last modified: 2012-05-31
+# Table last modified: 2012-06-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -24,7 +24,7 @@ our %ZIP_TABLE = (
     '017' => '(?:(?:8(?:5(?:10|67|85|5[05])|686)|029[23]))',
     '018' => '(?:(?:1(?:39[23]|59[56]|79[23]|692)|3(?:59[2356]|39[23]|192)|4(?:39[2-5]|69[23]|494)|0(?:49[23]|[16]92|795)|5(?:79[23]|292)|2498))',
     '019' => '(?:(?:1(?:397|692)|079[23]|2[16]92))',
-    '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|5[045]|7[278]|2[02]|6[167]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:9[23568]|8[0-578])|59[2356]|49[356])))',
+    '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|5[045]|7[278]|2[02]|6[167]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:8[0-578]|9[2368])|59[2356]|49[356])))',
     '021' => '(?:8(?:5(?:11|44|55|77|0[1-46]|6[67])|6(?:04|11|33|87)))',
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
     '023' => '(?:(?:049[23]|850[12]|1192))',
@@ -104,21 +104,21 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016]|4[3489])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '101' => '(?:8(?:4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|22|77|8[0-35]|1[125689])|79[58]))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|1[0-24-689]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:20|55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|60|3[0-2568]|7[013]|2[0346]|4[0278]|8[08])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|60|3[0-2568]|7[013]|2[0346]|8[048]|4[0278])|0(?:06|60|77)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
-    '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
+    '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|8[0-578]|3[02-5]|1[0-28]|6[02-478]|5[0-2457])|5(?:8[025]|4[018]|6[02369]|3[138]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|86|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[013-5]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
-    '115' => '(?:8(?:5(?:[06]7|55|8[568]|1[01]|2[49])|(?:60|71)1))',
+    '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|(?:60|71)1))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[03568])|60[12]))',
     '121' => '(?:8(?:5(?:33|40|0[245]|2[0-4]|8[58]|5[05]|1[01])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
@@ -130,23 +130,23 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|8[125-7]|0[1458]|4[08]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|4[04]|0[13-578]|8[02-58]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
-    '143' => '(?:(?:85(?:28|70|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|5[0258]|1[145])|6501))',
+    '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
     '150' => '(?:8(?:5(?:45|3[03]|8[5-7]|2[25]|6[379]|5[05]|7[57]|1[0-24-7]|0[2357-9])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
-    '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|5[24589]|7[0-46-8]|9[01]|0[2-579])|6(?:00|7[1-7])|40[14]))',
+    '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|0[3-6]|4[3-5]|6[05-8]|2[0135]|3[0-369]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
-    '156' => '(?:8(?:5(?:22|33|55|8[578]|0[126]|1[01])|6(?:66|78)))',
+    '156' => '(?:8(?:5(?:22|33|55|8[58]|0[126]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|1[015]|3[13]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
@@ -197,16 +197,16 @@ our %ZIP_TABLE = (
     '208' => '(?:85(?:85|0[1-3]|5[05]))',
     '210' => '(?:(?:8(?:5(?:2[1-3]|5[027-9]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:11|6[68])))',
-    '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|5[1457]|7[026]|3[016])|602))',
+    '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|7[0267]|5[1457]|3[01])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[125]))',
-    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080))',
+    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080|711))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
-    '224' => '(?:8(?:5(?:10|78|8[05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
+    '224' => '(?:8(?:5(?:78|[18][05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
     '225' => '(?:85(?:[28]5|[56]0|13|3[59]|0[1-38]))',
     '226' => '(?:85(?:[25]5|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
@@ -217,11 +217,11 @@ our %ZIP_TABLE = (
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
-    '238' => '(?:(?:8(?:5(?:[04]1|33|8[058]|2[02]|6[57]|5[08]|1[01])|6[18]6)|029[28]))',
+    '238' => '(?:(?:8(?:5(?:33|41|8[058]|2[02]|6[57]|5[08]|1[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|8[58])|68[68]))',
     '240' => '(?:(?:85(?:[02]1|[45]0|15)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
-    '242' => '(?:8(?:5(?:[07]7|55)|6(?:01|10)))',
+    '242' => '(?:8(?:5(?:[07]7|[58]5)|6(?:01|10)))',
     '243' => '(?:(?:0(?:4(?:60|9[2-8]|8[3-689])|19[23578]|29[278]|392)|8(?:5(?:21|33|88|5[015]|7[17]|1[01]|0[15])|60[14])))',
     '244' => '(?:8(?:5(?:10|0[1-3]|6[69]|7[17]|2[28]|5[058]|8[589]|3[039])|601))',
     '245' => '(?:85(?:[16]0|01|42|89|5[0358]|7[57]))',
@@ -255,7 +255,7 @@ our %ZIP_TABLE = (
     '276' => '(?:85(?:01|80|2[34]))',
     '277' => '(?:8(?:5(?:1[158]|8[124-8]|0[13-57]|7[07]|6[156]|5[0146-8]|3[139]|2[12])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|77|5[05])|6(?:01|86)))',
-    '279' => '(?:8(?:5(?:30|41|67|5[0358]|2[125-7]|1[168]|8[58]|0[1-359])|686))',
+    '279' => '(?:8(?:5(?:30|41|67|5[0358]|2[125-79]|8[58]|1[1689]|0[1-35])|686))',
     '282' => '(?:8610)',
     '283' => '(?:(?:8(?:5(?:[01]1|55|88)|650)|0195))',
     '284' => '(?:8555)',
@@ -311,7 +311,7 @@ our %ZIP_TABLE = (
     '335' => '(?:8(?:5(?:22|33|55|8[58]|1[01]|0[1-35])|6(?:55|66)|792))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|0[568]|8[167]|5[58]|2[0256])|6(?:01|36|55)|760))',
     '337' => '(?:85(?:32|70|86|0[27]))',
-    '338' => '(?:8(?:5(?:8[056]|2[3-5]|6[67]|7[0157]|1[0235]|3[18]|4[01]|0[3468]|5[13578])|6(?:30|86)))',
+    '338' => '(?:8(?:5(?:8[056]|2[3-5]|0[3-68]|6[67]|7[0157]|1[0235]|3[18]|4[01]|5[13578])|6(?:30|86)))',
     '339' => '(?:8(?:5(?:21|39|66|85|0[19]|5[18]|1[01])|6(?:01|86)))',
     '340' => '(?:(?:8(?:5(?:24|33|77|5[015]|0[19]|8[58]|6[078]|1[01])|6(?:59|86|1[01]))|0(?:19[23]|295)))',
     '341' => '(?:85(?:01|5[058]|2[67]))',
@@ -323,12 +323,12 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[25]5|30|1[23]|4[09]|0[135-7])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-4])|1(?:19[23]|292)))',
-    '350' => '(?:(?:0(?:2(?:9[25]|8[02-9])|39[2-6]|49[3-6]|19[237])|1(?:3(?:9[28]|8[08])|1(?:81|9[26-8])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[0178])))',
+    '350' => '(?:(?:0(?:2(?:9[25]|8[02-9])|39[2-6]|49[3-6]|19[237])|1(?:1(?:81|9[24-8])|3(?:9[28]|8[08])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[0178])))',
     '351' => '(?:(?:8(?:5(?:[26]0|51|0[18]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
     '354' => '(?:85(?:33|77|8[05]|5[58]|0[13-5]|1[01]))',
-    '355' => '(?:(?:8(?:5(?:01|85)|60[1-6])|0(?:19[235]|39[25]|292)))',
+    '355' => '(?:(?:0(?:3(?:80|9[25])|19[235]|292)|8(?:5(?:01|85)|60[1-6])))',
     '356' => '(?:85(?:33|67|85|0[127]|5[056]|1[01]))',
     '357' => '(?:8(?:5(?:01|10|27|5[058]|8[58])|673))',
     '358' => '(?:85(?:[02]1|1[015]|[58][58]))',
@@ -384,7 +384,7 @@ our %ZIP_TABLE = (
     '408' => '(?:(?:85(?:[18]5|22|33|5[05])|01(?:88|92)))',
     '409' => '(?:(?:3(?:8(?:9[2-8]|8[01357-9])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
     '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|4[03-5]|3[0135]|7[05]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-6]|39[2-6])|3(?:29[23]|69[36])|0(?:39[568]|192)))',
-    '411' => '(?:8(?:6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|5(?:02|33|60|77|2[05]|5[15]|[14][01])|7(?:[45]0|[78]7|2[025]|3[01])))',
+    '411' => '(?:8(?:5(?:02|33|60|77|88|2[05]|5[15]|[14][01])|6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|7(?:[45]0|[78]7|2[025]|3[01])))',
     '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])))',
     '413' => '(?:(?:8(?:5(?:30|8[59]|0[25]|5[058]|6[067]|1[01])|6(?:26|78|1[18]))|0(?:29[238]|49[23]|196)))',
     '414' => '(?:8(?:5(?:11|5[05])|60[12]))',
@@ -415,14 +415,14 @@ our %ZIP_TABLE = (
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|8[08]|0[1-37]|1[0-2579]|4[035]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
     '442' => '(?:8(?:5(?:20|58|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|8[0-25-8]|7[35-7]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
-    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[2-4]|89[23])))',
+    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[23]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:23|31|50|0[16])|731))',
     '449' => '(?:029[2-4])',
-    '450' => '(?:(?:8(?:5(?:40|3[0238]|2[0-3]|6[17]|1[05]|7[57]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[148]|5[01])|7(?:11|30|65))|6133))',
-    '451' => '(?:8(?:5(?:[14]1|85|[25][015]|6[0158]|0[1-38]|7[0157])|6(?:50|88)|701))',
+    '450' => '(?:(?:8(?:5(?:40|3[0238]|6[17]|2[013]|1[05]|7[57]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[148]|5[01])|7(?:11|30|65))|6133))',
+    '451' => '(?:8(?:5(?:[14]1|85|5[015]|6[0158]|2[0-25]|0[1-38]|7[0157])|6(?:50|88)|701))',
     '452' => '(?:8(?:5(?:21|44|70|0[1-3]|6[1-79])|60[1-4]))',
     '453' => '(?:8(?:5(?:40|55|77|8[015]|6[57]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|7(?:58|65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
@@ -451,7 +451,7 @@ our %ZIP_TABLE = (
     '477' => '(?:85(?:21|38))',
     '478' => '(?:8(?:5(?:55|0[1-5])|6(?:01|4[01])))',
     '479' => '(?:8(?:5(?:01|55|77|1[018]|8[5689])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
-    '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-8])|298)))',
+    '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-9])|298)))',
     '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-58]|3[1359])|6(?:[08]1|15|78)))',
     '482' => '(?:8(?:5(?:01|30|55|1[01])|6(?:86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[2357])|70[14]))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|4[0-35-9]|1[124-9]|6[3568]|7[15-9]|8[14-79]|0[1-689]|3[014578])|6666))',
+    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|8[15-79]|7[1568]|4[0-35-9]|1[126-8]|6[368]|0[1-689]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -528,11 +528,11 @@ our %ZIP_TABLE = (
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:01|1[019]|5[03589]|8[58]|6[01])|6(?:[01]1|5[18])|729))',
-    '560' => '(?:85(?:79|80|4[38]|5[25]|6[0157]|3[12]))',
+    '560' => '(?:85(?:05|79|80|4[38]|5[25]|6[0157]|3[12]))',
     '561' => '(?:85(?:[06]1|20|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|8[0568]|[05][58]|6[0278])|686))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
-    '564' => '(?:8(?:5(?:23|67|5[015]|0[13]|8[05]|1[15])|6(?:80|5[01])))',
+    '564' => '(?:8(?:5(?:23|67|85|5[015]|0[13]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|65))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
     '567' => '(?:8(?:5(?:[34]0|[56]7|78|85|1[015]|2[0135]|0[125])|6(?:51|80)))',
@@ -717,7 +717,7 @@ our %ZIP_TABLE = (
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
     '760' => '(?:8(?:5(?:1\d|0[1-578]|5[0-2457-9]|[36][0-246-9]|2[0-578]|4[4-7]|8[0-8]|7[0-69])|6(?:71|6[0178]|3[04689]|5[05]|[14][48]|2[013-6]|8[06-8]|0[13478])))',
-    '761' => '(?:(?:0(?:1(?:8[5-9]|9[2-8])|39[3-7]|79[35]|[46]92)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-5])|8(?:5(?:[014]1|33|77|8[25689]|6[67]|5[58])|601)|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
+    '761' => '(?:(?:0(?:1(?:8[5-9]|9[2-8])|39[3-7]|79[35]|[46]92)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|8(?:5(?:[014]1|33|77|8[25689]|6[67]|5[58])|601)|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:1[0-268]|0[1-478])|60[358]))',
     '764' => '(?:85(?:20|0[1-3578]|1[01]))',
@@ -805,7 +805,7 @@ our %ZIP_TABLE = (
     '846' => '(?:8501)',
     '847' => '(?:(?:8(?:5(?:11|88)|601)|0(?:19[23]|39[23])|1292))',
     '848' => '(?:(?:0492|8501))',
-    '849' => '(?:(?:85(?:14|22|77|0[1-3]|[58][58])|1(?:[124]92|39[24]|698)|3(?:19[23]|29[23])|419[2-5]|239[235]|519[238]|059[27]))',
+    '849' => '(?:(?:85(?:14|22|77|0[1-3]|[58][58])|1(?:39[2-4]|[124]92|698)|3(?:19[23]|29[23])|419[2-5]|239[235]|519[238]|059[27]))',
     '850' => '(?:8(?:5(?:2[0-35]|8[0568]|1[0-258]|7[057]|5[0158]|0[13-8]|6[0367]|3[0167]|4[013578])|6(?:22|45|7[78]|1[018]|5[02]|6[268]|8[5-8]|0[236])))',
     '851' => '(?:(?:0(?:49[2-478]|19[358]|39[25]|592)|2(?:1(?:85|9[5-8])|29[28]|492)|3(?:39[24]|[25]92)))',
     '852' => '(?:8(?:5(?:32|66|77|88|1[015]|0[17-9]|4[24]|5[58]|2[0-378])|601|794))',
@@ -816,7 +816,7 @@ our %ZIP_TABLE = (
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[23578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
-    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|1[1589]|8[168]|0[1-68]|6[08])|79[57]))',
+    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|1[1589]|8[168]|0[1-68]|6[08])|7(?:39|9[57])))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[235-8])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[24-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|6[13]95|7292))',
     '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[35]|0[139]|1[0-2]|8[08]|5[125])|7(?:20|44|1[06]|9[34]|0[12])|5(?:[127]0|55|0[258])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
@@ -875,7 +875,7 @@ our %ZIP_TABLE = (
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:0[1-9]|2[0-25]|3[0135-9]|4[014]|7[0357]|1[0-3578]|5[0-46-8]|6[0135-8]|8[035-8])|6(?:0[125-79]|7[0146-8]|2[01356]|8[01568]|5[4-8]|4[0-248]|3[01378]|6[0156]|1[0-69])|7(?:[67]7|30|0[137]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
-    '921' => '(?:8(?:5(?:5[0257]|4[14689]|3[0-269]|7[1-9]|2[02-79]|0[15-8]|8[0-47-9]|6[0-2457]|1[0-257-9])|6(?:01|3[079]|1[126]|[25][01])|798))',
+    '921' => '(?:8(?:5(?:5[025]|4[14689]|1[0-2578]|3[0-269]|7[1-9]|2[02-79]|0[15-8]|8[0-47-9]|6[0-2457])|6(?:01|3[079]|1[126]|[25][01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|1[156]|4[2-46]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:01|22|33|44|66|77|8[058]|5[58]|1[01])|68[68]))',
@@ -904,7 +904,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|765)|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|39[2-4]|59[24]|277)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|392)|5(?:49[2-4]|292)|039[23]|239[24]|8492))',
-    '950' => '(?:(?:8(?:5(?:20|6[05-7]|0[1-57]|7[0-25-79]|4[013-5]|5[0135-9]|1[489]|3[0-479]|8[0-35689])|6(?:6[018]|2[0-269]|0[1-368]|5[0145]|7[078]|4[01]|8[016]|[13][039])|7(?:09|5[013589]|2[0-3]|3[023578]|1[01578]|4[014-9]|9[48])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
+    '950' => '(?:(?:8(?:5(?:20|6[05-7]|0[1-57]|3[0-49]|7[0-25-79]|4[013-5]|5[0135-9]|1[489]|8[0-35689])|6(?:6[018]|0[1-368]|5[0145]|7[078]|4[01]|2[0-69]|8[016]|[13][039])|7(?:09|5[013589]|2[0-3]|3[023578]|1[01578]|4[014-9]|9[48])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
     '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|8[01568]|0[1-68]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|501)|019[23]))',
@@ -932,12 +932,12 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:2(?:39[2-4]|195|792)|1(?:[135]92|495)|0(?:69[56]|192)))',
-    '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|8[014-68]|4[023578]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|7[01457-9]|6[0156]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
+    '980' => '(?:(?:8(?:4(?:66|5[2-468]|7[78]|8[014-68]|4[023578]|2[0369]|1[0145]|3[013569]|0[1-358])|5(?:1[015]|4[3-6]|8[01358]|5[05]|3[13-5]|6[0156]|7[013-57-9]|0[15]|2[069])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-8]|2[12]|8[56]|7[017])|7(?:0[17]|9[2-578]))|6(?:0(?:55|88)|180)))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
     '983' => '(?:8(?:5(?:70|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|2[02378]|0[124679])|6(?:22|39|0[12])))',
     '984' => '(?:8(?:5(?:8[045]|7[057]|6[0178]|3[3589]|5[0-3578]|4[035]|2[125]|1[0-25689]|0[1-35])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
-    '985' => '(?:8(?:5(?:[15][015]|4[03]|2[0-2]|3[1-358]|0[12467])|6(?:55|0[17])))',
+    '985' => '(?:8(?:5(?:89|[15][015]|4[03]|2[0-2]|3[1-358]|0[12467])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
     '987' => '(?:(?:2(?:29[23]|59[23]|195|392)|0(?:19[25]|79[23]|595)|860[23578]|139[35]))',
     '988' => '(?:(?:039[23]|850[12]))',
